FileBox

Struct FileBox 

pub struct FileBox { /* private fields */ }
Represents a Save or Open File Dialog.

This is a builder struct, all functions return self, except the open or save method.

Examples

Generic open file:

use system_extensions::dialogues::filebox::FileBox;
use std::path::Path;

let result = FileBox::new().open();

println!("{}", result.expect("The file was not opened!").to_str().unwrap());

Generic save file:

use system_extensions::dialogues::filebox::FileBox;
use std::path::Path;

let result = FileBox::new().save("example.txt");

println!("{}", result.expect("The file was not saved!").to_str().unwrap());

Filters:

use system_extensions::dialogues::filebox::FileBox;
use std::path::Path;

let result = FileBox::new()
         .filter("PNG", "*.png")
         .filter("JPG", "*.jpg")
         .filter("GIF", "*.gif")
         .open();

println!("{}", result.expect("The file was not opened!").to_str().unwrap());

Save a file with a default directory:

use system_extensions::dialogues::filebox::FileBox;
use std::path::Path;

let result = FileBox::new()
         .filter("Text", "*.txt")
         .directory(Path::new("D:\\"))
         .save("example.txt");

println!("{}", result.expect("The file was not saved!").to_str().unwrap());

Implementations

Source

impl FileBox

pub fn new() -> FileBox

Create a new FileBox to open or save files.

Default Values

By default the Filter is set to a Vector with the all filter inside. (‘All’, ‘.’) By default there is not default directory.

pub fn clear_filters(self) -> Self

Clear the current filters. This is useful if you don’t want the ‘All’ filter.

pub fn set_filters(self, filters: Vec<Filter>) -> Self

Set the vector of filters.

Params

filters: Vec<Filter> -> The vector of filters to be used. (Replaces any existing filters).

pub fn filter(self, name: &str, ending: &str) -> Self

Add a filter to the file box. You may want to clear the filters first if you don’t want the Any filter.

Params

name: &str -> The name of the filter.
ending: &str -> The ending of the filter.

Example
use system_extensions::dialogues::filebox::FileBox;
FileBox::new().filter("Text", "*.*").open();
pub fn directory(self, path: &'static Path) -> Self

Set the default directory for the save or open dialog to display.
Not setting this causes the dialog to open the last displayed directory or the documents folder.

Params

path: &`static Path -> The path of the directory to display.

pub fn open(self) -> Option<PathBuf>

Display the open file dialog.

Returns

Option<PathBuf> -> The Path to the opened file. An empty Option means that the window was closed without opening anything.

pub fn save(self, suggested_name: &str) -> Option<PathBuf>

Display the save file dialog.

Params

suggested_name: &str -> The default name that is given when the dialog is displayed.

Returns

Option<PathBuf> -> The path to the saved file. An empty Option means that the window was closed without saving anything.