Module metadata
system_
extensions
0.0.4
Module metadata
Module Items
Modules
In crate system_
extensions
system_extensions
Module
metadata
Feature that involves additional file metadata editing.
Modules

attribute
Allows the editing of file attribute data. This includes setting a file to hidden and read-only.
time
Allows the editing of when a file was created, modified, and accessed.